<?php
/**
 * Block Template.
 *
 * @param array $block The block settings and attributes.
 * @param string $content The block inner HTML (empty).
 * @param bool $is_preview True during backend preview render.
 * @param int $post_id The post ID the block is rendering content against.
 */

$merchant_code = getenv('ROMEGA_VISKAN_MERCHANT');
$type = get_field('form_type');
$subscription_code = get_field('subscription_code');
$one_time_code = get_field('one_time_code');

$one_time_price = get_field('one_time_price');
$subscription_price = get_field('subscription_price');

$is_subscription = $type === 'subscription';
$is_one_time = $type === 'one-time';
$is_combined = $type === 'combined';

$allowed_blocks = array('acf/terms');

$id = 'rb-order-form-' . $block['id'];
if (!empty($block['anchor'])) {
    $id = $block['anchor'];
}
$classes = 'rb-order-form';
if (!empty($block['className'])) {
    $classes .= ' ' . $block['className'];
}
if ($type === 'combined') {
    $classes .= ' rb-order-form--combined';
}
?>

<div class="<?php echo esc_attr($classes); ?>" data-type="<?php echo esc_attr($type); ?>">
    <?php if ($type === 'combined' && $one_time_code): ?>
        <div class="rb-order-form__type-selection">
            <input type="radio" id="subscription" name="purchase-type" value="<?php echo esc_attr($subscription_code); ?>"
                class="rb-order-form__hidden" checked>
            <label for="subscription" class="rb-order-form__type-button active">
                <?php esc_html_e('Abonnement', 'romega-blocks'); ?>
                <?php if ($subscription_price): ?>
                    <span class="__price">
                        <?php echo esc_html($subscription_price); ?>
                    </span>
                <?php endif; ?>
            </label>

            <input type="radio" id="one-time" name="purchase-type" value="<?php echo esc_attr($one_time_code); ?>"
                class="rb-order-form__hidden">
            <label for="one-time" class="rb-order-form__type-button">
                <?php esc_html_e('Engangskjøp', 'romega-blocks'); ?>
                <?php if ($one_time_price): ?>
                    <span class="__price">
                        <?php echo esc_html($one_time_price); ?>
                    </span>
                <?php endif; ?>
            </label>
        </div>
    <?php endif; ?>

    <form id="<?php echo esc_attr($id); ?>" action="https://express.streamline.shop/purchases-v2" method="POST">
        <input type="hidden" name="merchant" value="<?php echo esc_attr($merchant_code); ?>">
        <input type="hidden" id="page_input" name="page" value="<?php echo esc_attr($subscription_code); ?>">
        <input type="hidden" name="country" value="NO">
        <input type="hidden" name="languageCode" value="no">

        <?php if ($is_one_time || $is_combined) { ?>
            <input type="hidden" name="paymentMethod" id="payment_method_hidden" value="Kort">
        <?php } ?>

        <div class="rb-order-form__row">
            <div class="rb-order-form__group rb-order-form__group--half">
                <label class="rb-order-form__label"
                    for="firstName"><?php esc_html_e('Fornavn', 'romega-blocks'); ?></label>
                <input class="rb-order-form__input" type="text" id="firstName" name="firstName"
                    autocomplete="given-name" required>
            </div>
            <div class="rb-order-form__group rb-order-form__group--half">
                <label class="rb-order-form__label"
                    for="lastName"><?php esc_html_e('Etternavn', 'romega-blocks'); ?></label>
                <input class="rb-order-form__input" type="text" id="lastName" name="lastName" autocomplete="family-name"
                    required>
            </div>
        </div>
        <div class="rb-order-form__group">
            <label class="rb-order-form__label"
                for="invoiceAddress"><?php esc_html_e('Adresse', 'romega-blocks'); ?></label>
            <input class="rb-order-form__input" type="text" id="invoiceAddress" name="invoiceAddress"
                autocomplete="shipping street-address" required>
        </div>
        <div class="rb-order-form__row">
            <div class="rb-order-form__group rb-order-form__group--half">
                <label class="rb-order-form__label"
                    for="invoiceZipcode"><?php esc_html_e('Post nr', 'romega-blocks'); ?></label>
                <input class="rb-order-form__input" type="text" id="invoiceZipcode" name="invoiceZipcode"
                    autocomplete="shipping postal-code" required>
            </div>
            <div class="rb-order-form__group rb-order-form__group--half">
                <label class="rb-order-form__label"
                    for="invoiceCity"><?php esc_html_e('Sted', 'romega-blocks'); ?></label>
                <input class="rb-order-form__input" type="text" id="invoiceCity" name="invoiceCity"
                    autocomplete="shipping address-level2" required>
            </div>
        </div>
        <div class="rb-order-form__group">
            <label class="rb-order-form__label" for="email"><?php esc_html_e('Epost', 'romega-blocks'); ?></label>
            <input class="rb-order-form__input" type="email" id="email" name="email" autocomplete="email" required>
        </div>
        <div class="rb-order-form__group">
            <label class="rb-order-form__label"
                for="cellphone"><?php esc_html_e('Telefon nr', 'romega-blocks'); ?></label>
            <input class="rb-order-form__input" type="tel" id="cellphone" name="cellphone" autocomplete="tel" required>
        </div>

        <?php if ($is_subscription || $is_combined) { ?>
            <div class="rb-order-form__group" id="payment-method-selection">
                <label class="rb-order-form__label"><?php esc_html_e('Betalingsmåte', 'romega-blocks'); ?></label>
                <div class="rb-order-form__radio-group">
                    <label class="rb-order-form__radio-label">
                        <input type="radio" name="paymentMethod" value="Kort" checked>
                        <?php esc_html_e('Kort', 'romega-blocks'); ?>
                    </label>
                    <label class="rb-order-form__radio-label">
                        <input type="radio" name="paymentMethod" value="Faktura">
                        <?php esc_html_e('Faktura', 'romega-blocks'); ?>
                    </label>
                </div>
            </div>
        <?php } ?>

        <div class="rb-order-form__group checkbox">
            <label class="rb-order-form__label">
                <input class="rb-order-form__checkbox" type="checkbox" id="betingelser" name="betingelser" required>
                <span>Jeg godtar <a href="/vilkar">vilkårene</a>.</span>
            </label>
        </div>

        <button type="submit" class="rb-order-form__submit" id="rb-order-form__submit-button">
            <?php esc_html_e('Prøv nå', 'romega-blocks'); ?>
        </button>
    </form>

    <?php if ($is_subscription || $is_combined) { ?>
        <div class="form-terms" id="form-terms-section">
            <InnerBlocks allowedBlocks="<?php echo esc_attr(wp_json_encode($allowed_blocks)); ?>" />
        </div>
    <?php } ?>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        const formContainer = document.querySelector('.rb-order-form');
        if (!formContainer) return;

        const form = formContainer.querySelector('form');
        const typeButtons = formContainer.querySelectorAll('.rb-order-form__type-button');
        const radioInputs = formContainer.querySelectorAll('input[name="purchase-type"]');
        const submitButton = formContainer.querySelector('#rb-order-form__submit-button');
        const termsSection = formContainer.querySelector('#form-terms-section');
        const paymentTypeContainer = formContainer.querySelector('#payment-method-selection');
        const paymentTypeHiddenField = formContainer.querySelector('#payment_method_hidden');
        const pageInput = formContainer.querySelector('#page_input');

        function setFormState(isSubscription) {
            const selectedRadio = formContainer.querySelector('input[name="purchase-type"]:checked');
            if (selectedRadio && pageInput) {
                pageInput.value = selectedRadio.value;
            }

            paymentTypeContainer.style.display = isSubscription ? 'block' : 'none';
            paymentTypeHiddenField.disabled = isSubscription;
            termsSection.classList.toggle('hidden', !isSubscription);
            submitButton.innerText = isSubscription ? 'Prøv nå' : 'Bestill';
        }

        if (formContainer.dataset.type === 'combined') {
            setFormState(true);
        }

        if (radioInputs.length) {
            radioInputs.forEach((radio, index) => {
                radio.addEventListener('change', function () {
                    typeButtons.forEach(btn => btn.classList.remove('active'));
                    typeButtons[index].classList.add('active');
                    setFormState(this.id === 'subscription');
                });
            });
        }
    });
</script>