<?php


$id = 'post-grid-' . $block['id'];
if (!empty($block['anchor'])) {
    $id = $block['anchor'];
}

$align_class = $block['align'] ? 'align' . $block['align'] : '';
$class_name = isset($block['className']) ? $block['className'] : "";

$post_type_acf = get_field('post_type');
$categories = get_field('categories');
$heading = get_field('heading');
$heading_type = get_field('heading_type');
$heading_size = get_field('heading_size');
$heading_color = get_field('heading_color');
$heading_align = get_field('heading_align');
$columns = get_field('columns');
$number_of_posts = get_field('number_of_posts');
$image = get_field('include_image');
$img_width = get_field('image_width');
$img_height = get_field('image_height');
$img_border_radius = get_field('image_border_radius');
$title = get_field('include_title');
$title_type = get_field('title_type');
$title_size = get_field('title_size');
$title_color = get_field('title_color');
$title_align = get_field('title_align');
$excerpt = get_field('include_excerpt');
$excerpt_length = get_field('excerpt_length');
$excerpt_size = get_field('excerpt_size');
$excerpt_color = get_field('excerpt_color');
$excerpt_align = get_field('excerpt_align');
$read_more = get_field('include_read_more');
$read_more_text = get_field('read_more_text');
$read_more_size = get_field('read_more_size');
$read_more_color = get_field('read_more_color');
$read_more_align = get_field('read_more_align');
$view_mode = get_field('view_mode');
?>

<section id="<?php echo esc_attr($id); ?>" class="post-grid <?php echo esc_attr($class_name . ' ' . $align_class); ?>">
    <h<?php echo esc_html($heading_type); ?>
        style="color:<?php echo esc_attr($heading_color); ?>; text-align:<?php echo esc_attr($heading_align); ?>; font-size:<?php echo esc_attr($heading_size); ?>px;">
        <?php echo esc_html($heading); ?>
    </h<?php echo esc_html($heading_type); ?>>

    <?php if ($view_mode === 'scroll'): ?>
        <div class="scroll-container">
            <button class="scroll-button left-button" aria-label="Scroll left"></button>

            <div class="scroll-view">
            <?php else: ?>
                <div class="grid grid-<?php echo esc_attr($columns); ?>">
                <?php endif; ?>

                <?php
                $args = array(
                    'post_type' => $post_type_acf,
                    'posts_per_page' => $number_of_posts,
                );
                if (!empty($categories)) {
                    $args['tax_query'] = array(
                        array(
                            'taxonomy' => 'category',
                            'field' => 'term_id',
                            'terms' => $categories,
                            'operator' => 'IN',
                        )
                    );
                }

                $news_posts = new WP_Query($args);
                if ($news_posts->have_posts()):
                    while ($news_posts->have_posts()):
                        $news_posts->the_post(); ?>

                        <div class="loop-post <?php echo esc_attr(join(' ', get_post_class())); ?>"
                            id="post-<?php the_ID(); ?>">
                            <?php if ($image): ?>
                                <a href="<?php the_permalink(); ?>">
                                    <div class="img-container">
                                        <img src="<?php echo esc_url(get_the_post_thumbnail_url()); ?>"
                                            style="height:<?php echo esc_attr($img_height); ?>; width:<?php echo esc_attr($img_width); ?>; border-radius:<?php echo esc_attr($img_border_radius); ?>px;">
                                    </div>
                                </a>
                            <?php endif; ?>

                            <?php if ($title): ?>
                                <h<?php echo esc_html($title_type); ?>
                                    style="text-align:<?php echo esc_attr($title_align); ?>; font-size:<?php echo esc_attr($title_size); ?>px;">
                                    <a href="<?php the_permalink(); ?>" class="post-title"><?php the_title(); ?></a>
                                </h<?php echo esc_html($title_type); ?>>
                            <?php endif; ?>

                            <?php if (get_post_type() === 'produkt'):
                                $price = get_field('price', get_the_ID());
                                if ($price !== '' && $price !== null): ?>
                                    <div class="price">Intropris:<span class="gold"> <?php echo esc_html($price); ?>,-</span></div>
                                <?php else: ?>
                                    <div class="price">Ingen pris satt</div>
                                <?php endif;
                            endif; ?>

                            <?php if ($excerpt):
                                $excerpt_content = get_the_excerpt();
                                $new_excerpt = strip_tags($excerpt_content);
                                $new_excerpt = preg_replace('/\[[^\]]*\]/', '', $new_excerpt);
                                $new_excerpt = str_replace('Read More...', '', $new_excerpt);
                                // Del teksten i ord
                                $words = explode(' ', $new_excerpt);
                                // Behold kun de første 10 ordene
                                if (count($words) > 10) {
                                    $words = array_slice($words, 0, 10);
                                    $new_excerpt = implode(' ', $words) . '...';
                                }
                                ?>
                                <p class="excerpt"
                                    style="text-align:<?php echo esc_attr($excerpt_align); ?>; font-size:<?php echo esc_attr($excerpt_size); ?>px; color:<?php echo esc_attr($excerpt_color); ?>;">
                                    <?php echo esc_html($new_excerpt); ?>
                                </p>
                            <?php endif; ?>

                            <?php if ($read_more) { ?>
                                <?php if (get_post_type() == 'produkt') { ?>
                                    <div class="read-more-product">
                                        <a href="<?php the_permalink(); ?>" class="read-more-link"><?php echo $read_more_text; ?></a>
                                    </div>
                                <?php } else { ?>
                                    <div class="read-more">
                                        <a href="<?php the_permalink(); ?>" class="read-more-link"><?php echo $read_more_text; ?></a>
                                    </div>
                                <?php } ?>
                            <?php } ?>
                        </div>

                    <?php endwhile;
                    wp_reset_postdata();
                endif; ?>

            </div>

            <?php if ($view_mode === 'scroll'): ?>

                <button class="scroll-button right-button" aria-label="Scroll right"></button>
            </div>
        <?php endif; ?>


</section>

<?php if ($view_mode === 'scroll'): ?>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const scrollContainer = document.querySelector('.scroll-view');
            const leftButton = document.querySelector('.left-button');
            const rightButton = document.querySelector('.right-button');
            const postWidth = scrollContainer.querySelector('.loop-post').offsetWidth;


            leftButton.style.display = 'none';

            function updateButtonVisibility() {

                if (scrollContainer.scrollLeft === 0) {
                    leftButton.style.display = 'none';
                } else {
                    leftButton.style.display = 'block';
                }

                if (scrollContainer.scrollLeft >= scrollContainer.scrollWidth - scrollContainer.clientWidth) {
                    rightButton.style.display = 'none';
                } else {
                    rightButton.style.display = 'block';
                }
            }

            leftButton.addEventListener('click', () => {
                scrollContainer.scrollBy({
                    left: -postWidth,
                    behavior: 'smooth'
                });
            });

            rightButton.addEventListener('click', () => {
                scrollContainer.scrollBy({
                    left: postWidth,
                    behavior: 'smooth'
                });
            });

            scrollContainer.addEventListener('scroll', updateButtonVisibility);
        });
    </script>
<?php endif; ?>