<?php
/**
 * Block Template.
 * @param array $block The block settings and attributes.
 * @param string $content The block inner HTML (empty).
 * @param bool $is_preview True during backend preview render.
 * @param int $post_id The post ID the block is rendering content against.
 */

$id = 'search-filter-' . $block['id'];
if (!empty($block['anchor'])) {
    $id = $block['anchor'];
}

$classes = 'search-filter-display';
if (!empty($block['className'])) {
    $classes .= ' ' . $block['className'];
}

// Prepare searchparams array for JavaScript
$js_searchparams = array();
if (have_rows('searchparams')) {
    while (have_rows('searchparams')) {
        the_row();
        $js_searchparams[] = array(
            'name' => get_sub_field('name'),
            'prefix' => get_sub_field('prefix'),
            'suffix' => get_sub_field('suffix')
        );
    }
}
?>
<div id="<?php echo esc_attr($id); ?>" class="<?php echo esc_attr($classes); ?>">
    <?php if (!empty($js_searchparams)): ?>
        <?php foreach ($js_searchparams as $param): ?>
            <div class="filter-item" data-param="<?php echo esc_attr($param['name']); ?>">
                <div class="filter-item__content">
                    <?php if ($param['prefix']): ?>
                        <span class="filter-item__prefix"><?php echo esc_html($param['prefix']); ?></span>
                    <?php endif; ?>

                    <span class="filter-item__value"></span>

                    <?php if ($param['suffix']): ?>
                        <span class="filter-item__suffix"><?php echo esc_html($param['suffix']); ?></span>
                    <?php endif; ?>
                </div>
            </div>
        <?php endforeach; ?>
    <?php else: ?>
        <p>No filters applied.</p>
    <?php endif; ?>

    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const validParams = <?php echo json_encode($js_searchparams); ?>;
            const urlParams = new URLSearchParams(window.location.search);

            validParams.forEach(param => {
                const element = document.querySelector(`.filter-item[data-param="${param.name}"]`);
                const valueElement = element?.querySelector('.filter-item__value');

                const urlValue = urlParams.get(param.name)

                if (valueElement && urlValue) {
                    valueElement.textContent = urlValue;
                    element.classList.add('has-value');
                } else if (element) {
                    element.style.display = 'none';
                }
            });
        });
    </script>
</div>